@@ -1,6 +1,5 @@
-from .sundata import LightingInformation, LightPeriod, Position
+from .sundata import SunData, LightPeriod, Position
 from .sundata import (
-    lighting_is,
     get_sun_altitude,
     get_lighting_period_after,
     get_lighting_period_before,
