@@ -1,10 +1,13 @@
 from datetime import datetime
+
 from src.sundata import Position, get_sun_altitude
 
+
 def test_get_altitude():
     pos = Position(51.772938, 0.102310)
     when = datetime(2023, 2, 12, 23, 3)
-    assert get_sun_altitude(pos, when) == -49.20252290488592
+    altitude = get_sun_altitude(pos, when)
+    assert round(altitude, 2) == -49.20
 
 
 def test_get_altitude_zero():
